import type { UploadAjaxError } from './ajax';
import type { Awaitable } from '../types/index';
import type { ExtractPropTypes } from 'vue';
import type Upload from './upload.vue';
export declare const uploadListTypes: readonly ["text", "picture-card"];
export declare const genFileId: () => number;
export declare type UploadStatus = 'ready' | 'uploading' | 'success' | 'fail';
export interface UploadProgressEvent extends ProgressEvent {
    percent: number;
}
export interface UploadRequestOptions {
    action: string;
    method: string;
    data: Record<string, string | Blob | [string | Blob, string]>;
    filename: string;
    file: File;
    headers: Headers | Record<string, string | number | null | undefined>;
    onError: (evt: UploadAjaxError) => void;
    onProgress: (evt: UploadProgressEvent) => void;
    onSuccess: (response: any) => void;
    withCredentials: boolean;
}
export interface UploadFile {
    name: string;
    percentage?: number;
    status: UploadStatus;
    size?: number;
    response?: unknown;
    uid: number;
    url?: string;
    raw?: UploadRawFile;
}
export declare type UploadUserFile = Omit<UploadFile, 'status' | 'uid'> & Partial<Pick<UploadFile, 'status' | 'uid'>>;
export declare type UploadFiles = UploadFile[];
export interface UploadRawFile extends File {
    uid: number;
}
export declare type UploadRequestHandler = (options: UploadRequestOptions) => XMLHttpRequest | Promise<unknown>;
export interface UploadHooks {
    beforeUpload: (rawFile: UploadRawFile) => Awaitable<void | undefined | null | boolean | File | Blob>;
    beforeRemove: (uploadFile: UploadFile, uploadFiles: UploadFiles) => Awaitable<boolean>;
    onRemove: (uploadFile: UploadFile, uploadFiles: UploadFiles) => void;
    onChange: (uploadFile: UploadFile, uploadFiles: UploadFiles) => void;
    onPreview: (uploadFile: UploadFile) => void;
    onSuccess: (response: any, uploadFile: UploadFile, uploadFiles: UploadFiles) => void;
    onProgress: (evt: UploadProgressEvent, uploadFile: UploadFile, uploadFiles: UploadFiles) => void;
    onError: (error: Error, uploadFile: UploadFile, uploadFiles: UploadFiles) => void;
    onExceed: (files: File[], uploadFiles: UploadUserFile[]) => void;
}
export declare const uploadBaseProps: {
    action: {
        type: StringConstructor;
        default: string;
    };
    headers: {
        type: import("vue").PropType<Record<string, any> | Headers>;
    };
    method: {
        type: StringConstructor;
        default: string;
    };
    data: {
        type: ObjectConstructor;
        default: () => import("../types").Mutable<{}>;
    };
    multiple: {
        type: BooleanConstructor;
        default: boolean;
    };
    webkitdirectory: {
        type: BooleanConstructor;
        default: boolean;
    };
    name: {
        type: StringConstructor;
        default: string;
    };
    withCredentials: BooleanConstructor;
    showFileList: {
        type: BooleanConstructor;
        default: boolean;
    };
    accept: {
        type: StringConstructor;
        default: string;
    };
    uploadPrecent: {
        type: NumberConstructor;
        default: number;
    };
    isLoading: {
        type: BooleanConstructor;
        default: boolean;
    };
    type: {
        type: StringConstructor;
        default: string;
    };
    fileList: {
        type: import("vue").PropType<UploadUserFile[]>;
        default: () => [];
    };
    autoUpload: {
        type: BooleanConstructor;
        default: boolean;
    };
    listType: {
        type: StringConstructor;
        values: readonly ["text", "picture-card"];
        default: string;
    };
    httpRequest: {
        type: import("vue").PropType<UploadRequestHandler>;
        default: UploadRequestHandler;
    };
    disabled: BooleanConstructor;
    limit: NumberConstructor;
};
export declare const uploadProps: {
    beforeUpload: {
        type: import("vue").PropType<(rawFile: UploadRawFile) => Awaitable<void | undefined | null | boolean | File | Blob>>;
        default: () => void;
    };
    beforeRemove: {
        type: import("vue").PropType<(uploadFile: UploadFile, uploadFiles: UploadFiles) => Awaitable<boolean>>;
    };
    onRemove: {
        type: import("vue").PropType<(uploadFile: UploadFile, uploadFiles: UploadFiles) => void>;
        default: () => void;
    };
    onChange: {
        type: import("vue").PropType<(uploadFile: UploadFile, uploadFiles: UploadFiles) => void>;
        default: () => void;
    };
    onPreview: {
        type: import("vue").PropType<(uploadFile: UploadFile) => void>;
        default: () => void;
    };
    onSuccess: {
        type: import("vue").PropType<(response: any, uploadFile: UploadFile, uploadFiles: UploadFiles) => void>;
        default: () => void;
    };
    onProgress: {
        type: import("vue").PropType<(evt: UploadProgressEvent, uploadFile: UploadFile, uploadFiles: UploadFiles) => void>;
        default: () => void;
    };
    onError: {
        type: import("vue").PropType<(error: Error, uploadFile: UploadFile, uploadFiles: UploadFiles) => void>;
        default: () => void;
    };
    onExceed: {
        type: import("vue").PropType<(files: File[], uploadFiles: UploadUserFile[]) => void>;
        default: () => void;
    };
    action: {
        type: StringConstructor;
        default: string;
    };
    headers: {
        type: import("vue").PropType<Record<string, any> | Headers>;
    };
    method: {
        type: StringConstructor;
        default: string;
    };
    data: {
        type: ObjectConstructor;
        default: () => import("../types").Mutable<{}>;
    };
    multiple: {
        type: BooleanConstructor;
        default: boolean;
    };
    webkitdirectory: {
        type: BooleanConstructor;
        default: boolean;
    };
    name: {
        type: StringConstructor;
        default: string;
    };
    withCredentials: BooleanConstructor;
    showFileList: {
        type: BooleanConstructor;
        default: boolean;
    };
    accept: {
        type: StringConstructor;
        default: string;
    };
    uploadPrecent: {
        type: NumberConstructor;
        default: number;
    };
    isLoading: {
        type: BooleanConstructor;
        default: boolean;
    };
    type: {
        type: StringConstructor;
        default: string;
    };
    fileList: {
        type: import("vue").PropType<UploadUserFile[]>;
        default: () => [];
    };
    autoUpload: {
        type: BooleanConstructor;
        default: boolean;
    };
    listType: {
        type: StringConstructor;
        values: readonly ["text", "picture-card"];
        default: string;
    };
    httpRequest: {
        type: import("vue").PropType<UploadRequestHandler>;
        default: UploadRequestHandler;
    };
    disabled: BooleanConstructor;
    limit: NumberConstructor;
};
export declare type UploadProps = ExtractPropTypes<typeof uploadProps>;
export declare type UploadInstance = InstanceType<typeof Upload>;
